package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.carto.IFeatureRenderer;
import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.carto.SimpleRenderer;

import org.w3c.dom.Element;

import de.intevation.mxd.utils.MapToXMLUtils;

/**
 * Reads simple renderer information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class SimpleRendererReader
implements IRendererReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(SimpleRendererReader.class);

    /**
     * Private member.
     */
    private ISymbol symbol;
    private SimpleRenderer renderer;
    private Element layer;
    private MapToXMLUtils util;


    public SimpleRendererReader(IFeatureRenderer renderer)
    throws Exception {
        logger.debug("constructor()");
        if(renderer instanceof SimpleRenderer) {
            this.renderer = (SimpleRenderer)renderer;
        }
        else{
            throw new Exception ("Not an instance of SimpleRenderer!");
        }
    }

    /**
     * Setter for the parent XML element.
     *
     * @param parent The XML parent node.
     */
    public void setParent(Element parent) {
        this.layer = parent;
    }

    /**
     * Setter for the XML document helper.
     *
     * @param util The helper class for storing map information.
     */
    public void setUtil(MapToXMLUtils util) {
        this.util = util;
    }

    /**
     * Reads the renderer attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        Element rendererElement;
        rendererElement = util.addRenderer(layer);

        rendererElement.setAttribute("label", renderer.getLabel());
        rendererElement.setAttribute("description", renderer.getDescription());
        symbol = renderer.getSymbol();

        MarkerSymbolReader markerReader = new MarkerSymbolReader();
        LineSymbolReader lineReader = new LineSymbolReader();
        FillSymbolReader fillReader = new FillSymbolReader();
        if(markerReader.canRead(symbol)) {
            markerReader.setSymbol(symbol);
            markerReader.setUtil(util);
            markerReader.setParent(rendererElement);
            markerReader.read();
        }
        else if(lineReader.canRead(symbol)) {
            lineReader.setSymbol(symbol);
            lineReader.setUtil(util);
            lineReader.setParent(rendererElement);
            lineReader.read();
        }
        else if(fillReader.canRead(symbol)) {
            fillReader.setSymbol(symbol);
            fillReader.setUtil(util);
            fillReader.setParent(rendererElement);
            fillReader.read();
        }
        else {
            logger.debug("No known Symbol type: " + symbol.getClass().toString());
        }
        return layer;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
